
/*Program written by Matthew Nelson
   Jan 3, 2016
   for Fresno Ideaworks
   http://fresnoideaworks.org

   If you need help please come to Tech Tuesdays
   or Sumobot Saturdays at Fresno Ideaworks

  Suggestions:
  -Experiment with the setSpeed() command to optimize your robot.
  -If your motors reverse when told to go forward reverse the +- wires on the motor shield.
*/

#include <Wire.h>
#include <Adafruit_MotorShield.h>
#include "utility/Adafruit_PWMServoDriver.h"
#include "SRF05.h"
#include <avr/interrupt.h>
#include <IRremote.h>

// Create the motor shield object with the default I2C address
Adafruit_MotorShield AFMS = Adafruit_MotorShield();

// Select which 'port' M1, M2, M3 or M4 your motors are wired to.
Adafruit_DCMotor *rightmotor = AFMS.getMotor(3); //right motor connected to M3
Adafruit_DCMotor *leftmotor = AFMS.getMotor(4); //left motor connected to M4

// trigPin, echoPin, MaxDist, readInterval
// Trigger is conneccted to pin 5, Echo to 4, 30 cm max distance, read every time through the loop
SRF05 Sensor(5, 4, 30, 0);
const int frontsensorPin = 3;     // front line sensor is connected to pin 3, blue wire
const int rearsensorPin = 2;      // rear line sensor is connected to pin 2, green wire
const int button1Pin = 8;  // The button is hooked up to digital pin 8
const int ledPin =  13;    // LED wire is hooked up to digital pin 13
const int RECV_PIN = 11;
const int white = 1;
const int black = 0;

int frontsensorState = black;         // when the program starts the front line sensor is seeing black
int rearsensorState = black;          // when the program starts the rear line sensor is seeing black
int button1State = HIGH;  // variable to hold the pushbutton state
boolean turnedon = false;  // Once the inital delay has been completed turned on is set to true

IRrecv irrecv(RECV_PIN);

decode_results results;
unsigned long CurrentValue = 0;
unsigned long stored = 45953231;
unsigned long left = 45983831;
unsigned long right = 45967511;
unsigned long up = 45991991;
unsigned long down = 45951191;
unsigned long menu = 45959351;
//http://www.binaryhexconverter.com/hex-to-decimal-converter

void setup()
{
  Serial.begin(9600); // Required to receive debugging info in the Serial Monitor, viewable in the Tools menu

  irrecv.enableIRIn(); // Start the receiver

  Serial.println("Fresno Ideaworks Arduinobot starting up...");
  Serial.println("Remote Control Mode");
  Sensor.Unlock = true; // Designed to unlock the SRF04 ultrasonic sensor when it locks up
  Sensor.Distance = 0; // Sets the sensor distance to an initial value of zero
  AFMS.begin();  //required for the motor shield

  pinMode(ledPin, OUTPUT);  // Set up the LED pin to be an output
}

void loop() {

  if (irrecv.decode(&results)) {
    //  Serial.println(results.value, HEX);
    CurrentValue = results.value;
    if (CurrentValue == left) {
      Serial.println("Left");
      spinleft();
    }
    if (CurrentValue == right) {
      Serial.println("Right");
      spinright();
    }
        if (CurrentValue == menu) {
      Serial.println("Right");
      reverse();
    }
    if (CurrentValue == up) {
      Serial.println("Up");
      forward();  //Turn both motors on, bot moves forward
    }
    if (CurrentValue == down) {
      Serial.println("Down");
      stopmotors();
    }
    irrecv.resume(); // Receive the next value
  }
  delay(100);
}

  //This procedure makes the bot move forward
  void forward()
  {
    Serial.println("Moving forward");
    rightmotor->setSpeed(75); //Sets the right motor speed 0-255
    rightmotor->run(FORWARD);
    leftmotor->setSpeed(75); //Sets the left motor speed 0-255
    leftmotor->run(FORWARD);
  }

  //This procedure makes the bot move backward
  void reverse()
  {
    stopmotors();
    Serial.println("Moving backward");
    rightmotor->setSpeed(75); //Sets the right motor speed 0-255
    rightmotor->run(BACKWARD);
    leftmotor->setSpeed(75); //Sets the left motor speed 0-255
    leftmotor->run(BACKWARD);
  }

  //This procedure makes the bot move spin to the right when viewed from above
  void spinright()
  {
    stopmotors();
    Serial.println("Spinning right");
    rightmotor->setSpeed(55); //Sets the right motor speed 0-255
    rightmotor->run(BACKWARD);
    leftmotor->setSpeed(55); //Sets the left motor speed 0-255
    leftmotor->run(FORWARD);
    delay (250);
    stopmotors();
  }

  //This procedure makes the bot move spin to the left when viewed from above
  void spinleft()
  {
    stopmotors();
    Serial.println("Spinning left");
    rightmotor->setSpeed(55); //Sets the right motor speed 0-255
    rightmotor->run(FORWARD);
    leftmotor->setSpeed(55); //Sets the left motor speed 0-255
    leftmotor->run(BACKWARD);
    delay (250);
    stopmotors();
  }

  //This procedure stops both motors
  void stopmotors()
  {
    Serial.println("Stopping both motors");
    rightmotor->run(RELEASE); //turn off the right motor
    leftmotor->run(RELEASE); //turn off the left motor
  }




